.. fwdpy11 documentation master file, created by
   sphinx-quickstart on Mon Mar 20 12:22:19 2017.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to fwdpy11's documentation!
===================================

.. toctree::
    :caption: Contents:

.. toctree::
    :caption: Miscellaneous notes
    :maxdepth: 1

    misc/changelog
    misc/upgrade_path
    misc/deprecated
    misc/pubs
    misc/developersguide

.. toctree::
    :caption: Installation and setup
    :maxdepth: 1

    pages/userenv

.. toctree::
    :caption: Concepts
    :maxdepth: 2

    pages/definitions

.. toctree::
    :caption: Tutorials

    pages/tutorial.rst
    pages/advancedtopics

.. toctree::
    :caption: Objects and concepts

    pages/softselection
    pages/mvdes
    pages/tsoverview
    pages/tstypes
    pages/tablefs.rst
    pages/recorders

.. toctree::
    :caption: Technical details

    technical/genetic_values
    technical/writingplugins


.. toctree::
    :caption: Data types and functions
    :maxdepth: 2

    pages/types
    pages/genetic_values
    pages/gvalue_to_fitness
    pages/gvaluenoise
    pages/regiontypes
    pages/datamatrix
    pages/model_params
    pages/functions
    pages/demographic_models
    pages/tskit_tools
    pages/gslrandom.rst

.. toctree::
    :caption: References
    :maxdepth: 1

    misc/references

.. toctree::
    :caption: Examples

    examples/bgs
    examples/gss
    examples/recorder
    examples/migtest
    examples/localadaptation
    examples/IM
    examples/gss_divergent_optima
    examples/precapitation
    examples/recapitation
    examples/pysnowdrift

.. todolist::

